==> phplist-2.10.5p0.tgz: lists/admin/lan/pt-br/members.php <==
<?php
$lan = array(
  'You do not have enough priviliges to view this page' => 'Voc&ecirc; n&atilde;o tem privil&eacute;gios suficientes para ver esta p&aacute;gina',
  'Add a user' => 'Adicionar um usu&aacute;rio',
  'add user' => 'Adicionar Usu&acute;rio',
  'Members of' => 'Membros de',
  'Tag all users in this page' => 'Rotular todos os usu&acute;rios desta p&acute;gina',
  'back to this list' => 'voltar para esta lista',
  'Download users on this list as a CSV file' => 'Baixar usu&acute;rios desta lista em arquivo CSV',
  'Please enter a listid' => 'Por favor, insira a identifica&ccedil;&atilde;o da lista (listid)',
  'Processing' => 'Processando',
  'users were moved to' => 'os usu&aacute;rios foram movidos para',
  'users were copied to' => 'os usu&aacute;rios foram copiados para',
  'users were deleted from this list' => 'os usu&aacute;rios foram removidos desta lista',
  'Users found, click add to add this user' => 'Usu&aacute;rios encontrados, clique para Adicionar para incluri este usu&aacute;rio',
  'Add' => 'Adicionar',
  'No user found with that email' => 'Nenhum usu&aacute;rio com este email foi encontrado',
  'Inserting user' => 'Inserindo usu&aacute;rio',
  'User added' => 'Usu&aacute;rio adicionado',
  'Deleting' => 'Apagando',
  'Done' => 'Conclu&iacute;do',
  'Users on this list' => 'Usu&aacute;rios desta lista',
  'Listing user' => 'Listando us&aacute;rio',
  'to' => 'to',//in sentence 'listing user 1  to  50'
  'Listing user 1 to 50' => 'Listando us&acute;rio de 1 a 50',
  'Members' => 'Membros',
  'confirmed' => 'confirmado',
  'tag' => 'rotular',
  'del' => 'apagar',
  'Delete'=>'Apagar',
  '# msgs' => '# msgs',
  '# rss' => '# rss',
  'rss freq' => 'freq&uml;&ecirc;ncia rss',
  'last sent' => '&uacute;ltima enviada',
  'What to do with "Tagged" users' => 'O que fazer com os usu&aacute;rios "Rotulados"',
  'This will only process the users in this page that have the "Tag" checkbox checked' => 'Isso s&oacute; processar&aacute; os usu&aacute;rios desta p&aacute;gina que estejam com a op&ccedil;&atilde;o "R&oacute;tulo" marcada',
  'delete' => 'Apagar',
  'move' => 'Mover',
  'copy' => 'Copiar',
  'nothing' => 'Nada',
  'to' => 'para', # as in destination
  'from this list' => 'desta lista',
  'What to do with all users' => 'O que fazer com todos os usu&aacute;rios',
  'This will process all users on this list' => 'Isso processar&aacute; todos os usu&aacute;rios desta lista',
  'do it' => 'concluir',
  
  
);
?>

==> phplist-2.10.19p0.tgz: lists/admin/lan/pt-br/members.php <==
<?php
$lan = array(
  'You do not have enough priviliges to view this page' => 'Voc&ecirc; n&atilde;o tem privil&eacute;gios suficientes para ver esta p&aacute;gina',
  'Add a user' => 'Adicionar um usu&aacute;rio',
  'add user' => 'Adicionar Usu&aacute;rio',
  'Members of' => 'Membros de',
  'Tag all users in this page' => 'Marcar todos os usu&aacute;rios desta p&aacute;gina',
  'back to this list' => 'voltar para esta lista',
  'Download users on this list as a CSV file' => 'Baixar usu&aacute;rios desta lista em arquivo CSV',
  'Please enter a listid' => 'Por favor, insira a identifica&ccedil;&atilde;o da lista (listid)',
  'Processing' => 'Processando',
  'users were moved to' => 'os usu&aacute;rios foram movidos para',
  'users were copied to' => 'os usu&aacute;rios foram copiados para',
  'users were deleted from this list' => 'os usu&aacute;rios foram removidos desta lista',
  'Users found, click add to add this user' => 'Usu&aacute;rios encontrados, clique para Adicionar para incluri este usu&aacute;rio',
  'Add' => 'Adicionar',
  'No user found with that email' => 'Nenhum usu&aacute;rio com este email foi encontrado',
  'Inserting user' => 'Inserindo usu&aacute;rio',
  'User added' => 'Usu&aacute;rio adicionado',
  'Deleting' => 'Apagando',
  'Done' => 'Conclu&iacute;do',
  'Users on this list' => 'Usu&aacute;rios desta lista',
  'Listing user' => 'Listando us&aacute;rio',
  'to' => 'to',//in sentence 'listing user 1  to  50'
  'Listing user 1 to 50' => 'Listando us&acute;rio de 1 a 50',
  'Members' => 'Membros',
  'confirmed' => 'confirmado',
  'tag' => 'marcar',
  'del' => 'apagar',
  'Delete'=>'Apagar',
  '# msgs' => '# msgs',
  '# rss' => '# RSS',
  'rss freq' => 'freq&uuml;&ecirc;ncia RSS',
  'last sent' => '&uacute;ltima enviada',
  'What to do with "Tagged" users' => 'O que fazer com os usu&aacute;rios "Marcados"',
  'This will only process the users in this page that have the "Tag" checkbox checked' => 'Somente os usu&aacute;rios MARCADOS ser&atilde;o afetados.',
  'delete' => 'Apagar',
  'move' => 'Mover',
  'copy' => 'Copiar',
  'nothing' => 'Nada',
  'to' => 'para', # as in destination
  'from this list' => 'desta lista',
  'What to do with all users' => 'O que fazer com todos os usu&aacute;rios',
  'This will process all users on this list' => 'Este procedimento ser executado para TODOS os usu&aacute;rios.',
  'do it' => 'concluir',
  
  
);
?>
